@@ -13,6 +13,10 @@ GLOBAL_LOG_LEVEL = LogLevel.INFO
 
 
 def set_global_log_level(log_level: LogLevel):
+    """
+    Set global logging level. The default is INFO.
+    :param log_level: valid log level
+    """
     global GLOBAL_LOG_LEVEL
     GLOBAL_LOG_LEVEL = log_level
 
